@@ -105,17 +105,16 @@ class WinOSClient:
 
     _URL = 'https://pypi.org/project/pywinrm/'
 
-    def __init__(
-            self,
-            host: str = None,
-            username: str = None,
-            password: str = None,
-            logger_enabled: bool = True):
+    def __init__(self,
+                 host: str = None,
+                 username: str = None,
+                 password: str = None,
+                 logger_enabled: bool = True):
 
         self.host = host
         self.username = username
         self.password = password
-        self.logger = plogger.logger(self.__class__.__name__, enabled=logger_enabled)
+        self.logger = plogger.logger('WinOSClient', enabled=logger_enabled)
 
     def __str__(self):
         return (f'Local host: {self.get_current_os_name_local()}\n'
@@ -196,7 +195,7 @@ class WinOSClient:
         response = None
         transport_sent = ' PS' if ps else 'CMD'
 
-        self.logger.info(f'[{self.host} {transport_sent} -->] {command}')
+        self.logger.info(f'[{self.host} {transport_sent} ->] {command}')
 
         try:
             if ps:  # Use PowerShell
@@ -212,7 +211,7 @@ class WinOSClient:
                     transport='ntlm')
                 response = client.run_cmd(command, [arg for arg in args])
 
-            self.logger.info(f'[{self.host} {transport_sent} <--] {response}')
+            self.logger.info(f'[{self.host} {transport_sent} <-] {response}')
             return ResponseParser(response, command=command)
 
         # Catch exceptions
@@ -797,6 +796,18 @@ class WinOSClient:
         os.makedirs(path, exist_ok=True)
         return self.exists_local(path)
 
+    def get_directory_size(self, path: str) -> int:
+        r"""Get directory size in bytes
+
+        :param path: Directory full path. Example, C:\test | D:
+        :return: 515325611
+        """
+
+        cmd = f'(Get-ChildItem "{path}" -Recurse | Measure Length -Sum).Sum'
+        result = int(self.run_ps(cmd).stdout)
+
+        return result
+
     def unzip(self, path: str, target_directory: str):
         r"""Extract .zip archive to destination folder on remote server.
 
@@ -1340,6 +1351,7 @@ class WinOSClient:
             self.logger.warning(f'Date adjusted to {date}. Remote session was broken after date changing. {err}')
             return self.run_ps('Get-Date').stdout
 
+    # ------------------- DISK --------------------
     def is_disk_offline(self, disk_number: int) -> bool:
         """Is underline disk offline?
 
@@ -1384,9 +1396,10 @@ class WinOSClient:
         result = self.run_ps_local(cmd)
         return result.ok
 
-    def get_disks(self, dimension: str = None) -> list[dict]:
+    def get_disks(self, disk_number: int = None, dimension: str = None) -> dict:
         """Get Disks info
 
+        :param disk_number: Disk disk_number. 1, 2, 3...
         :param dimension: Bytes by default. MB (rounded) | GB (rounded)
         """
 
@@ -1400,8 +1413,8 @@ class WinOSClient:
 
         disks = self.run_ps('Get-Disk | ConvertTo-Json').json()
 
-        result = [
-            {
+        result = {
+            disk['DiskNumber']: {
                 'DiskNumber': disk['DiskNumber'],
                 'NumberOfPartitions': disk['NumberOfPartitions'],
                 'PartitionStyle': disk['PartitionStyle'],
@@ -1423,20 +1436,21 @@ class WinOSClient:
                 'Model': disk['Model'],
                 f'Size': converter(disk['Size']) if dim else disk['Size'],
 
-            } for disk in disks
-        ]
+            } for disk in disks}
 
         msg = f'NOTE: Size will be rounded up to integer ({dim}). {result}' if dim else result.__str__()
         self.logger.info(msg)
-        return result
+        return result.get(disk_number) if disk_number else result
 
-    def get_volumes(self, dimension: str = None) -> list[dict]:
+    def get_volumes(self, letter: str = None, dimension: str = None) -> dict:
         """Get virtual volumes info.
 
+        :param letter: Volume letter. C, D, E...
         :param dimension: Bytes by default. MB (rounded) | GB (rounded)
         :return:
         """
 
+        vol_name = letter.removesuffix('\\').removesuffix(':') if letter else letter
         dim = '' if dimension is None else dimension  # Just to shorten var name
         conv = None
 
@@ -1447,8 +1461,8 @@ class WinOSClient:
 
         disks = self.run_ps('Get-Volume | ConvertTo-Json').json()
 
-        result = [
-            {
+        result = {
+            disk['DriveLetter']: {
                 'DriveLetter': disk['DriveLetter'],
                 'FileSystemLabel': disk['FileSystemLabel'],
                 'Size': conv(disk['Size']) if dim else disk['Size'],
@@ -1463,11 +1477,11 @@ class WinOSClient:
                 'UniqueId': disk['UniqueId'],
 
             } for disk in disks
-        ]
+        }
 
         msg = f'NOTE: Size will be rounded up to integer ({dim}). {result}' if dim else result.__str__()
         self.logger.info(msg)
-        return result
+        return result.get(vol_name) if vol_name else result
 
     def get_volumes_count(self, skip_cd_rom: bool = False) -> int:
         """Count initialized volumes.
